nxp-pac

Crates

git

Versions

lpc55s16

Flavors

DcdcPowerProfileLow1

Struct DcdcPowerProfileLow1 

#[repr(transparent)]
pub struct DcdcPowerProfileLow1(pub u32);
no description available

Tuple Fields

0: u32

Implementations

Source

impl DcdcPowerProfileLow1

pub const fn rtrimoffet(&self) -> u8

Adjust the offset voltage of BJT based comparator.

pub const fn set_rtrimoffet(&mut self, val: u8)

Adjust the offset voltage of BJT based comparator.

pub const fn rsensetrim(&self) -> u8

Adjust Max inductor peak current limiting.

pub const fn set_rsensetrim(&mut self, val: u8)

Adjust Max inductor peak current limiting.

pub const fn dtestenable(&self) -> bool

Enable Digital test signals.

pub const fn set_dtestenable(&mut self, val: bool)

Enable Digital test signals.

pub const fn setcurve(&self) -> u8

Bandgap calibration parameter.

pub const fn set_setcurve(&mut self, val: u8)

Bandgap calibration parameter.

pub const fn setdc(&self) -> u8

Bandgap calibration parameter.

pub const fn set_setdc(&mut self, val: u8)

Bandgap calibration parameter.

pub const fn dtestsel(&self) -> u8

Select the output signal for test.

pub const fn set_dtestsel(&mut self, val: u8)

Select the output signal for test.

pub const fn iscaleenable(&self) -> bool

Modify COT behavior.

pub const fn set_iscaleenable(&mut self, val: bool)

Modify COT behavior.

pub const fn forcebypass(&self) -> bool

Force bypass mode.

pub const fn set_forcebypass(&mut self, val: bool)

Force bypass mode.

pub const fn trimautocot(&self) -> u8

Change the scaling ratio of the feedforward compensation.

pub const fn set_trimautocot(&mut self, val: u8)

Change the scaling ratio of the feedforward compensation.

pub const fn forcefullcycle(&self) -> bool

Force full PFM PMOS and NMOS cycle.

pub const fn set_forcefullcycle(&mut self, val: bool)

Force full PFM PMOS and NMOS cycle.

pub const fn lcenable(&self) -> bool

Change the range of the peak detector of current inside the inductor.

pub const fn set_lcenable(&mut self, val: bool)

Change the range of the peak detector of current inside the inductor.

pub const fn toff(&self) -> u8

Constant Off-Time calibration input.

pub const fn set_toff(&mut self, val: u8)

Constant Off-Time calibration input.

pub const fn toffenable(&self) -> bool

Enable Constant Off-Time feature.

pub const fn set_toffenable(&mut self, val: bool)

Enable Constant Off-Time feature.