nxp-pac

Crates

git

Versions

lpc55s16

Flavors

Usbcfg

Struct Usbcfg 

#[repr(transparent)]
pub struct Usbcfg(pub u32);
no description available

Tuple Fields

0: u32

Implementations

Source

impl Usbcfg

pub const fn xo32m_ready_time_out_ms(&self) -> u8

no description available

pub const fn set_xo32m_ready_time_out_ms(&mut self, val: u8)

no description available

pub const fn usb_speed(&self) -> u8

USB_SPEED[7:0]= 0x00 : USB High Speed Module used for ISP 0x01 : USB Full SPeed Module used for ISP 0x02 : Neither USB High Speed module nor USB Full Speed module used for ISP 0x03 - 0xFF : RESERVED

pub const fn set_usb_speed(&mut self, val: u8)

USB_SPEED[7:0]= 0x00 : USB High Speed Module used for ISP 0x01 : USB Full SPeed Module used for ISP 0x02 : Neither USB High Speed module nor USB Full Speed module used for ISP 0x03 - 0xFF : RESERVED

pub const fn usb_use_xo32m_capa_banks(&self) -> bool

Enable the use of Crystal 32 MHz internal Capa Banks during the configuration of the High Speed USB for ISP: 0: Disable Crystal 32 MHz CapaBanks. 1: Enable Crystal 32 MHz CapaBanks.

pub const fn set_usb_use_xo32m_capa_banks(&mut self, val: bool)

Enable the use of Crystal 32 MHz internal Capa Banks during the configuration of the High Speed USB for ISP: 0: Disable Crystal 32 MHz CapaBanks. 1: Enable Crystal 32 MHz CapaBanks.